Stan Math Library: stan/math/prim/mat/fun/sort_indices_desc.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

sort_indices_desc.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_SORT_INDICES_DESC_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_SORT_INDICES_DESC_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/prim/mat/meta/index_type.hpp>
6 #include <stan/math/prim/mat/fun/sort_indices.hpp>
7 #include <algorithm> // std::sort
8 #include <iostream>
9 #include <vector>
10
11 namespace stan {
12
13 namespace math {
14
22 template <typename C>
23 std::vector<int> sort_indices_desc(const C& xs) {
24 return sort_indices<false>(xs);
25 }
26
27
28 }
29 }
30 #endif
stan
Definition: log_sum_exp.hpp:8
sort_indices.hpp
index_type.hpp
Eigen.hpp
stan::math::sort_indices_desc
std::vector< int > sort_indices_desc(const C &xs)
Return a sorted copy of the argument container in ascending order.
Definition: sort_indices_desc.hpp:23

[ Stan Home Page ] © 2011–2016, Stan Development Team.